@@ -20,7 +20,7 @@ class BasicValidator(Validator):
         """
         super().__init__(conditions)
 
-    def isCandidate(self, stock: Stock) -> bool:
+    def validation(self, stock: Stock) -> bool:
         """
         Parameters
         ----------
